<?php
/* 
Plugin Name: Wellthemes Latest Tweets
Plugin URI: http://wellthemes.com
Description: A widget to display the latest tweets.
Version: 1.0
Author: Well Themes
Author URI: http://wellthemes.com
License: GPL v2
*/ 

/**
 * Include required files
 */
if ( !class_exists('tmhOAuth') ) {
	require_once 'lib/tmhOAuth.php';
	require_once 'lib/tmhUtilities.php';
}
	
/**
 * Register plugin settings
 */
register_activation_hook(__FILE__, 'wellthemes_twitter_install');
register_deactivation_hook(__FILE__, 'wellthemes_twitter_uninstall');
add_action('admin_menu', 'wellthemes_twitter_admin_menu_create');
add_action('widgets_init', create_function('', 'return register_widget("wellthemes_twitter_widget");')); 

function wt_enqueue_styles() {
    wp_enqueue_style( 'wt_tweets', plugins_url('wt_tweets/tweets.css') );
}

add_action( 'admin_enqueue_scripts', 'wt_enqueue_styles' );
/**
 * Function to set the default values
 */
function wellthemes_twitter_install() {

	$plugin_options = array(
		'twitter_username' => '',
		'twitter_data' => NULL,
		'last_access' => time(),
		'time_limit' => 5,
		'tweets_count' => 5,
		'show_avatar' => true,
		'time_format' => 'D jS M y H:i',
		'show_powered_by' => false,
		'version' => '1.0',
		'consumer_key' => '',
		'consumer_secret' => '',
		'access_token' => '',
		'access_secret' => '',
		'show_retweets' => false
	);		
	
	add_option('wt_twitter_settings', $plugin_options);
	
}

/**
 * Remove plugin settings when uninstalling
 */	
function wellthemes_twitter_uninstall() {
	delete_option('wt_twitter_settings');
}

/**
 * Create the admin menu
 */	
function wellthemes_twitter_admin_menu_create() {
	add_options_page('Tweets Settings', 'Wellthemes: Latest Tweets', 'administrator', __FILE__, 'wt_twitter_settings');	
}

/**
 * Get twitter status
 */	
function wellthemes_get_twitter_data() {

	$options = get_option('wt_twitter_settings', true);
	
	$tmhOAuth = new tmhOAuth(
					array(
						'consumer_key' => $options['consumer_key'],
						'consumer_secret' => $options['consumer_secret'],
						'user_token' => $options['access_token'],
						'user_secret' => $options['access_secret'],
						'curl_ssl_verifypeer' => false 
					)
				);
 
	$request_array = array();
	$request_array['screen_name'] = $options['twitter_username'];
	$request_array['count'] = $options['tweets_count'];
	$request_array['include_rts'] = $options['show_retweets'];
 	$code = $tmhOAuth->request('GET', $tmhOAuth->url('1.1/statuses/user_timeline'), $request_array);
 	$response = $tmhOAuth->response['response'];
	$tweets = json_decode($response, true);
	$options['twitter_data'] = $tweets;
	
	update_option('wt_twitter_settings', $options);	
	}
		
/**
 * Process links in the tweets
 */	 
function wellthemes_process_tweet_links($text) {

	$text = preg_replace('@(https?://([-\w\.]+)+(d+)?(/([\w/_\.]*(\?\S+)?)?)?)@', '<a href="$1">$1</a>',  $text);
	$text = preg_replace('/@(\w+)/', '<a href="http://twitter.com/$1">@$1</a>', $text);
	$text = preg_replace('/\s#(\w+)/', ' <a href="http://search.twitter.com/search?q=%23$1">#$1</a>', $text);
	
	return $text;

}
 
/**
 * Display recent tweets
 */	 
function wellthemes_show_recent_tweets() {

	$options = get_option('wt_twitter_settings', true);
	$get_data = false;
		
	if(!isset($options['twitter_data'])) {
		$get_data = true;
	}
		
	if(time() - $options['last_access'] > $options['time_limit'] * 60) {
		$get_data = true;
		$options['last_access'] = time();
		update_option('wt_twitter_settings', $options);
	}
		
	if($get_data) {			
		$asdf = wellthemes_get_twitter_data();			
	}
	
	$options = get_option('wt_twitter_settings', true);
	$tweets = $options['twitter_data'];
	$result = "";
	$image_url = $tweets[0]['user']['profile_image_url'];
	$twitter_username = $tweets[0]['user']['screen_name'];

	if($options['show_avatar']) { ?>
			
			<div class="twitter-header">
				<div class="twitter-avatar"><img src="<?php echo $image_url; ?>" /></div>
				<div class="twitter-profile-info">
					<h3><a href="https://www.twitter.com/<?php echo $twitter_username; ?>" >@<?php echo $twitter_username; ?></a></h3>
					<p class="twitter-profile-desc"><?php echo $tweets[0]['user']['description']; ?></p>
				</div>
			</div>
		
		<?php
		} 
	
	$limit = $options['tweets_count'];
	
	$i = 0;
	echo "<ul class='tweets-list list'>";
	
	foreach($tweets as $tweet) {
		
		$tweet_text = $tweet['text'];
		$processed_tweet = "";
		
		if(isset($tweets['errors'][0]['code'])) {
			_e('Feed currently unavailable.', 'wellthemes');			
		} else {
			echo "<li><div class='tweet-wrap'>";
			if(isset($tweet['retweeted_status'])) {
				$first = current(explode(":", $tweet_text));
				$whole_tweet = $first.": ";
				$whole_tweet .= $tweet['retweeted_status']['text'];

				$processed_tweet = wellthemes_process_tweet_links($whole_tweet);
				echo "<p class='tweet'>".$processed_tweet."</p>";
			} else {
				$processed_tweet = wellthemes_process_tweet_links($tweet['text']);
				echo "<p class='tweet'>".$processed_tweet."</p>";
			}
					
			$date = date($options['time_format'], strtotime($tweet['created_at']));
			echo "<p class='date'>".$date."</p>";
			
			if($i == $limit - 1) {
				break;
			}
				
			$i = $i + 1;
			echo "</div></li>";
		}		
	}
	echo "</ul>";
	
		
	if($options['show_powered_by']) { ?>
		<div class="powered-by">
			<?php _e('Powered by ', 'wellthemes')?><a href="<?php echo esc_url(__('http://wellthemes.com/', 'wellthemes')); ?>" target="_blank"><?php _e('wellthemes', 'wellthemes'); ?></a>
		</div>		
		<?php
	}		

}
 
/**
 * Display settings form
 */	 
function wt_twitter_settings() {

	$wt_twitter_settings = get_option('wt_twitter_settings', true);
	$message = '';
		
	if(isset($_POST['wt_username'])) {
	
		$wt_twitter_settings['twitter_username'] = stripslashes($_POST['wt_username']);
		$wt_twitter_settings['consumer_key'] = stripslashes($_POST['wt_consumer_key']);
		$wt_twitter_settings['consumer_secret'] = stripslashes($_POST['wt_consumer_secret']);
		$wt_twitter_settings['access_token'] = stripslashes($_POST['wt_access_token']);
		$wt_twitter_settings['access_secret'] = stripslashes($_POST['wt_access_secret']);		
		$wt_twitter_settings['tweets_count'] = (int) $_POST['wt_tweets_count'];
		$wt_twitter_settings['show_retweets'] = (isset($_POST['wt_show_retweets'])) ? true : false;
		$wt_twitter_settings['time_format'] = stripslashes($_POST['wt_time_format']);
		$wt_twitter_settings['time_limit'] = (int) $_POST['wt_cache_time'];
		$wt_twitter_settings['show_avatar'] = (isset($_POST['wt_show_avatar'])) ? true : false;		
		$wt_twitter_settings['show_powered_by'] = (isset($_POST['wt_show_powered_by'])) ? true : false;
		
		update_option('wt_twitter_settings', $wt_twitter_settings);
		$message = true;
	}
	
	$wellthemes_options = get_option('wt_twitter_settings', true);
	?>
        
    <form method="post" class="wellthemes-plugin-form" action="">
		
		<div class="wellthemes-plugin-form-wrap">
			<h2 class="wt-plugin-title"><?php _e('Wellthemes Latest Tweets Plugin Settings', 'wellthemes'); ?></h2>
			
			<?php if($message) { ?>		
				<div class="updated">
					<p><strong><?php _e('Settings updated successfully', 'wellthemes'); ?></strong></p>
				</div>			
			<?php } ?>
	
			<h3><?php _e('Twitter API Settings', 'wellthemes');?></h3>
			
			<div class="field">
				<label for="wt_username"><?php _e('Twitter username', 'wellthemes'); ?></label>
				<input type="text" name="wt_username" id="wt_username" value="<?php echo esc_attr($wellthemes_options['twitter_username']); ?>" />
				<span class="description"><?php _e('Enter your twitter username', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<label for="wt_consumer_key"><?php _e('Consumer key', 'wellthemes'); ?></label>
				<input type="text" name="wt_consumer_key" id="wt_consumer_key" value="<?php echo $wellthemes_options['consumer_key']; ?>" />
				<span class="description"><?php _e('Enter your consumer key here.', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<label for="wt_consumer_secret"><?php _e('Consumer secret', 'wellthemes'); ?></label>
					<input type="text" name="wt_consumer_secret" id="wt_consumer_secret" value="<?php echo $wellthemes_options['consumer_secret']; ?>" />
				<span class="description"><?php _e('Enter your consumer secret key here.', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<label for="wt_access_token"><?php _e('Access token', 'wellthemes'); ?></label>
				<input type="text" name="wt_access_token" id="wt_access_token" value="<?php echo $wellthemes_options['access_token']; ?>" />
				<span class="description"><?php _e('Enter your access token key here.', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<label for="wt_access_secret"><?php _e('Access token secret', 'wellthemes'); ?></label>
				<input type="text" name="wt_access_secret" id="wt_access_secret" size="70" value="<?php echo $wellthemes_options['access_secret']; ?>" />
				<span class="description"><?php _e('Enter your access token secret key here.', 'wellthemes'); ?></span>
			</div>
			
			<h3><?php _e('Twitter Plugin Settings', 'wellthemes');?></h3>
				
			<div class="field">	
				<label for="wt_tweets_count"><?php _e('Number of tweets', 'wellthemes'); ?></label>
				<input type="text" name="wt_tweets_count" id="wt_tweets_count" value="<?php echo $wellthemes_options['tweets_count']; ?>" />
				<span class="description"><?php _e('How many tweets are shown.', 'wellthemes'); ?></span>
			</div>
			
			<div class="field">	
				<label for="wt_show_retweets"><?php _e('Show retweets', 'wellthemes'); ?></label>
				 <input type="checkbox" name="wt_show_retweets" id="wt_show_retweets" value="true" <?php if($wellthemes_options['show_retweets'] == true) { ?>checked="checked"<?php } ?> />
				<span class="description inline-desc"><?php _e('Check this if you want to include retweets in your feed.', 'wellthemes'); ?></span>
			</div>
			
			<div class="field">	
				<label for="wt_time_format"><?php _e('Time format', 'wellthemes'); ?></label>
				<input type="text" name="wt_time_format" id="wt_time_format" value="<?php echo esc_html($wellthemes_options['time_format']); ?>" />
				<span class="description"><?php _e('The time format.', 'wellthemes'); ?></span>
			</div>
			
			<div class="field">	
				<label for="wt_cache_time"><?php _e('Twitter feed refresh (in minutes)', 'wellthemes'); ?></label>
				<input type="text" name="wt_cache_time" id="wt_cache_time" value="<?php echo $wellthemes_options['time_limit']; ?>" />
				<span class="description"><?php _e('In how many minutes does the Twitter feed refresh.', 'wellthemes'); ?></span>
			</div>
					
			<div class="field">	
				<label for="wt_show_avatar"><?php _e('Show profile box', 'wellthemes'); ?></label>
				<input type="checkbox" name="wt_show_avatar" id="wt_show_avatar" value="true" <?php if($wellthemes_options['show_avatar'] == true) { ?>checked="checked"<?php } ?> />
				<span class="description inline-desc"><?php _e('Show the profile box before tweets (including the avatar).', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<label for="wt_show_powered_by"><?php _e('Show powered by message', 'wellthemes'); ?></label>
				<input type="checkbox" name="wt_show_powered_by" id="wt_show_powered_by" value="true" <?php if($wellthemes_options['show_powered_by'] == true) { ?>checked="checked"<?php } ?> />
				<span class="description inline-desc"><?php _e('Show some love. It will look nice, promise.', 'wellthemes'); ?></span>
			</div>
	
			<div class="field">	
				<input type="submit" name="Submit" class="button-primary" value="<?php esc_attr_e('Update settings') ?>" />
			</div>
	
		</div><!-- /wellthemes-plugin-form-wrap -->
	</form>
	
	<?php
}
		
/**
 * Widget Settings
 */	 
class wellthemes_twitter_widget extends WP_Widget {
		
	function wellthemes_twitter_widget() {
		$widget_ops = array('classname' => 'widget_twitter', 'description' => 'A widget to display latest tweets.' );			
		$this->WP_Widget('wellthemes_twitter_widget', 'Well Themes: Latest Tweets', $widget_ops);
	}
		
	function widget($args, $instance) {
		
		extract($args);
		$title = apply_filters('widget_title', $instance['title']);
		
		echo $before_widget;
		if($title) {
			echo $before_title . $title . $after_title;
		}			
		
		wellthemes_show_recent_tweets();
		echo $after_widget;
	}
		
	function update($new_instance, $old_instance) {		
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
	    return $instance;
    }
		
	function form($instance) {	
	
		$defaults = array('title' => '');
		$instance = wp_parse_args( (array) $instance, $defaults );
		
       	//$title = esc_attr($instance['title']);
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'wellthemes') ?></label>
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>
		
		<?php 
	}

}

?>